@@ -1230,7 +1230,8 @@ impl pfr_table
     const PFR_TFLAG_REFDANCHOR: libc::c_uint = 0x00000020;
     const PFR_TFLAG_COUNTERS: libc::c_uint = 0x00000040;
 
-    unsafe fn new(pfrt_name: &str) -> PfResult<Self>
+    unsafe 
+    fn new(pfrt_name: &str) -> PfResult<Self>
     {
         if pfrt_name.len() >= PF_TABLE_NAME_SIZE-1
         {
@@ -1254,7 +1255,8 @@ impl pfr_table
         return Ok(table);
     }
 
-    unsafe fn pfr_add_tables(&mut self, fd: libc::c_int, size: libc::c_int, nadd: &mut libc::c_int, flags: libc::c_int, test: bool) -> PfResult<()>
+    unsafe 
+    fn pfr_add_tables(&mut self, fd: libc::c_int, size: libc::c_int, nadd: &mut libc::c_int, flags: libc::c_int, test: bool) -> PfResult<()>
     {
         if size < 0
         {
@@ -1281,7 +1283,8 @@ impl pfr_table
         return Ok(());
     }
 
-    unsafe fn pfr_add_addrs(
+    unsafe 
+    fn pfr_add_addrs(
         &mut self, 
         fd: libc::c_int, 
         mut b: PfrBuffer, 
@@ -1321,7 +1324,8 @@ impl pfr_table
         return Ok(());
     }
 
-    unsafe fn pfr_del_addrs(&mut self, fd: libc::c_int, mut b: PfrBuffer, ndel: &mut libc::c_int, flags: libc::c_int) -> PfResult<()>
+    unsafe 
+    fn pfr_del_addrs(&mut self, fd: libc::c_int, mut b: PfrBuffer, ndel: &mut libc::c_int, flags: libc::c_int) -> PfResult<()>
     {   
         if b.pfrb_caddr.len() == 0
         {
@@ -1347,7 +1351,8 @@ impl pfr_table
         return Ok(());
     }
 
-    unsafe fn pfr_tst_addrs(&mut self, fd: libc::c_int, mut b: PfrBuffer, nmatch: &mut libc::c_int, flags: libc::c_int) -> PfResult<()>
+    unsafe 
+    fn pfr_tst_addrs(&mut self, fd: libc::c_int, mut b: PfrBuffer, nmatch: &mut libc::c_int, flags: libc::c_int) -> PfResult<()>
     {   
         if b.pfrb_caddr.len() == 0
         {
@@ -1373,7 +1378,8 @@ impl pfr_table
         return Ok(());
     }
 
-    unsafe fn pfr_clr_addrs(&mut self, fd: libc::c_int, flags: libc::c_int, ndel: &mut libc::c_int) -> PfResult<()>
+    unsafe 
+    fn pfr_clr_addrs(&mut self, fd: libc::c_int, flags: libc::c_int, ndel: &mut libc::c_int) -> PfResult<()>
     {
         let mut io = pfioc_table::new_flush(self.clone(), flags);
 
@@ -1388,7 +1394,8 @@ impl pfr_table
         return Ok(());
     }
 
-    unsafe fn create_table(&mut self, fd: libc::c_int, test: bool) -> PfResult<()>
+    unsafe 
+    fn create_table(&mut self, fd: libc::c_int, test: bool) -> PfResult<()>
     {
         let mut nadd: libc::c_int = 0;
         let flags: libc::c_int = 0;
@@ -1408,7 +1415,8 @@ impl pfr_table
         return Ok(());
     }
 
-    unsafe fn add_addrs(&mut self, fd: libc::c_int, b: PfrBuffer, test: bool) -> PfResult<()>
+    unsafe 
+    fn add_addrs(&mut self, fd: libc::c_int, b: PfrBuffer, test: bool) -> PfResult<i32>
     {
         let mut nadd: libc::c_int = 0;
         let flags: libc::c_int = 0;
@@ -1419,24 +1427,26 @@ impl pfr_table
         #[cfg(feature = "log_to_stdout")]
         println!("{}/{} addresses added", nadd, pfrb_size);
 
-        return Ok(());
+        return Ok(nadd);
     }
 
-    unsafe fn del_addrs(&mut self, fd: libc::c_int, b: PfrBuffer) -> PfResult<()>
+    unsafe 
+    fn del_addrs(&mut self, fd: libc::c_int, b: PfrBuffer) -> PfResult<i32>
     {
-        let mut nadd: libc::c_int = 0;
+        let mut ndel: libc::c_int = 0;
         let flags: libc::c_int = 0;
 
         let pfrb_size = b.pfrb_caddr.len();
-        self.pfr_del_addrs(fd, b, &mut nadd, flags)?;
+        self.pfr_del_addrs(fd, b, &mut ndel, flags)?;
 
         #[cfg(feature = "log_to_stdout")]
         println!("{}/{} addresses deleted", nadd, pfrb_size);
 
-        return Ok(());
+        return Ok(ndel);
     }
 
-    unsafe fn tst_addrs(&mut self, fd: libc::c_int, b: PfrBuffer) -> PfResult<bool>
+    unsafe 
+    fn tst_addrs(&mut self, fd: libc::c_int, b: PfrBuffer) -> PfResult<i32>
     {
         let mut nmatch = 0;
         let flags: libc::c_int = 0;
@@ -1447,10 +1457,11 @@ impl pfr_table
         #[cfg(feature = "log_to_stdout")]
         println!("{}/{} addresses test", nmatch, pfrb_size);
 
-        return Ok(nmatch as usize == pfrb_size);
+        return Ok(nmatch);
     }
 
-    unsafe fn fls_addrs(&mut self, fd: libc::c_int) -> PfResult<i32>
+    unsafe 
+    fn fls_addrs(&mut self, fd: libc::c_int) -> PfResult<i32>
     {
         let mut ndel = 0;
         let flags: libc::c_int = 0;
@@ -1704,7 +1715,7 @@ impl Pf
     }
 
     pub unsafe 
-    fn pfctl_table<T: AsRef<str>>(&self, table_name: T, cmd: PfCmd) -> PfResult<()>
+    fn pfctl_table<T: AsRef<str>>(&self, table_name: T, cmd: PfCmd) -> PfResult<i32>
     {
         let tname = table_name.as_ref();
 
@@ -1726,54 +1737,55 @@ impl Pf
         //table.pfrt_name.copy_from_slice(tname.as_bytes());
 
         // https://github.com/freebsd/freebsd-src/blob/373ffc62c158e52cde86a5b934ab4a51307f9f2e/sbin/pfctl/pfctl_table.c :201
-        match cmd
-        {
-            PfCmd::Add{ hosts } =>
+        let ret_val = 
+            match cmd
             {
-                let mut b: PfrBuffer = PfrBuffer::new(Pfrb::PFRB_ADDRS);
-                //b.pfrb_type = Pfrb::PFRB_ADDRS as libc::c_int; //C b.pfrb_type = PFRB_ADDRS;
-
-                for host in hosts
+                PfCmd::Add{ hosts } =>
                 {
-                    b.load_addr_from_str(host, 0)?; //C if (load_addr(&b, argc, argv, file, 0))
-                }
+                    let mut b: PfrBuffer = PfrBuffer::new(Pfrb::PFRB_ADDRS);
+                    //b.pfrb_type = Pfrb::PFRB_ADDRS as libc::c_int; //C b.pfrb_type = PFRB_ADDRS;
 
-                table.create_table(self.fd, self.test)?;
+                    for host in hosts
+                    {
+                        b.load_addr_from_str(host, 0)?; //C if (load_addr(&b, argc, argv, file, 0))
+                    }
 
-                table.add_addrs(self.fd, b, self.test)?;
-            },
-            PfCmd::Delete{ hosts } => 
-            {
-                let mut b: PfrBuffer = PfrBuffer::new(Pfrb::PFRB_ADDRS);
-                //b.pfrb_type = Pfrb::PFRB_ADDRS as libc::c_int; //C b.pfrb_type = PFRB_ADDRS;
+                    table.create_table(self.fd, self.test)?;
 
-                for host in hosts
+                    table.add_addrs(self.fd, b, self.test)?
+                },
+                PfCmd::Delete{ hosts } => 
                 {
-                    b.load_addr_from_str(host, 0)?; //C if (load_addr(&b, argc, argv, file, 0))
-                }
+                    let mut b: PfrBuffer = PfrBuffer::new(Pfrb::PFRB_ADDRS);
+                    //b.pfrb_type = Pfrb::PFRB_ADDRS as libc::c_int; //C b.pfrb_type = PFRB_ADDRS;
 
-                table.del_addrs(self.fd, b)?;
-            },
-            PfCmd::Test{ hosts } => 
-            {
-                let mut b: PfrBuffer = PfrBuffer::new(Pfrb::PFRB_ADDRS);
-                //b.pfrb_type = Pfrb::PFRB_ADDRS as libc::c_int; //C b.pfrb_type = PFRB_ADDRS;
-                //b2.pfrb_type = Pfrb::PFRB_ADDRS as libc::c_int; //C b.pfrb_type = PFRB_ADDRS;
+                    for host in hosts
+                    {
+                        b.load_addr_from_str(host, 0)?; //C if (load_addr(&b, argc, argv, file, 0))
+                    }
 
-                for host in hosts
+                    table.del_addrs(self.fd, b)?
+                },
+                PfCmd::Test{ hosts } => 
                 {
-                    b.load_addr_from_str(host, 1)?; //C if (load_addr(&b, argc, argv, file, 1))
+                    let mut b: PfrBuffer = PfrBuffer::new(Pfrb::PFRB_ADDRS);
+                    //b.pfrb_type = Pfrb::PFRB_ADDRS as libc::c_int; //C b.pfrb_type = PFRB_ADDRS;
+                    //b2.pfrb_type = Pfrb::PFRB_ADDRS as libc::c_int; //C b.pfrb_type = PFRB_ADDRS;
+
+                    for host in hosts
+                    {
+                        b.load_addr_from_str(host, 1)?; //C if (load_addr(&b, argc, argv, file, 1))
+                    }
+
+                    table.tst_addrs(self.fd, b)?
+                },
+                PfCmd::Flush => 
+                {
+                    table.fls_addrs(self.fd)?
                 }
+            }; // match
 
-                table.tst_addrs(self.fd, b)?;
-            },
-            PfCmd::Flush => 
-            {
-                table.fls_addrs(self.fd)?;
-            }
-        }
-
-        return Ok(());
+        return Ok(ret_val);
     }
 
     
